#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_EQUAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_EQUAL_HPP_INCLUDED

#include <boost/simd/operator/include/functions/scalar/is_equal.hpp>

#endif
